@@ -4,7 +4,7 @@ TravelMode$choice2 <- TravelMode$choice == "yes"
 TravelMode$incair <- with(TravelMode, income * (mode == "air"))
 tm_cl <- mlogit(choice2 ~ gcost + wait + incair, data = TravelMode, shape = "long", choice = "choice", alt.var = "mode", reflevel = "car")
 # Greene table 21.15 first column
-#tm_hl <- mlogit(choice2 ~ gcost + wait + incair, data = TravelMode, shape = "long", choice = "choice", alt.var = "mode", reflevel = "car", heterosc = TRUE)
+tm_hl <- mlogit(choice2 ~ gcost + wait + incair, data = TravelMode, shape = "long", choice = "choice", alt.var = "mode", reflevel = "car", heterosc = TRUE)
 # Greene table 21.15 second column
 tm_nl <- mlogit(choice2 ~ gcost + wait + incair, data = TravelMode, shape = "long", choice = "choice", alt.var = "mode", reflevel = "car", nests = list(fly = "air", ground = c("bus", "car", "train")), unscaled = TRUE)
 
